epistoch.utils package
======================

Submodules
----------

epistoch.utils.plotting module
------------------------------

.. automodule:: epistoch.utils.plotting
    :members:
    :undoc-members:
    :show-inheritance:

epistoch.utils.stats module
---------------------------

.. automodule:: epistoch.utils.stats
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: epistoch.utils
    :members:
    :undoc-members:
    :show-inheritance:
